API de inventario de piezas de concesionario
Comenzando
Como se describe en la sección Compartición de Datos , DCP se trata de datos. Una pieza importante de datos es el inventario de Partes, Accesorios y Ropa (PAA) del concesionario (abreviado como inventario de partes), utilizado en muchos programas comerciales de BRP.
Estos incluyen, pero no se limitan a:
- La Gestión de Inventario Minorista es un programa de reposición automática.
- Buscar en el Concesionario es un sistema que permite a los consumidores ver un amplio inventario de piezas individuales para su concesionario elegido.
Tenga en cuenta que el intercambio de inventario de partes del concesionario ahora está incluido en el programa de certificación del concesionario: el concesionario pierde puntos cuando no comparte su inventario de partes.
Un objetivo es permitir que los concesionarios compartan sus inventarios de PAA directamente desde su DMS, en lugar de cargarlos manualmente desde BOSSWeb.
La API de Inventario de Partes del Concesionario proporciona dos servicios:
- Un servicio implica recibir el inventario del concesionario y actualizarlo en el sistema BRP.
- Un servicio para buscar un número de parte en el inventario del concesionario (Concesionario a Concesionario).
¿Dónde empezar? ¡Léeme primero!
Antes de comenzar a trabajar en esta API, debe leer las siguientes secciones si aún no las ha consultado:
Inventario de piezas del concesionario
Su DMS utiliza el servicio de inventario de piezas para enviar el inventario del concesionario a BRP. La información del inventario del concesionario debe actualizarse diariamente, incluso si el concesionario está cerrado.
Los datos del inventario del concesionario deben enviarse fuera del horario comercial del concesionario para garantizar que se envíen los valores más recientes.
El concesionario debe consentir el intercambio de datos antes de que envíe el inventario de repuestos del concesionario a BRP.
Su DMS solo debe enviar el inventario de repuestos de los concesionarios de BRP Powersports que hayan dado su consentimiento para compartir datos.
Consulte la sección Compartición de Datos para obtener más información sobre el intercambio de datos.
Localizador de Repuestos del Concesionario
El servicio de localizador de repuestos se utiliza para buscar un repuesto en el inventario de otro concesionario. La búsqueda está limitada a una distancia desde el concesionario solicitante, con un valor predeterminado de 200 km y un máximo de 8,000 km.
El servicio permite al concesionario encontrar un repuesto en otro concesionario que pueda estar disponible más rápidamente que pedir el repuesto a BRP, por ejemplo, si el repuesto está en pedido pendiente.
Para buscar la disponibilidad y ubicación de repuestos en el inventario de BRP, consulte la API de Inventario de Piezas
Información técnica
Características
Tipo de API | Tipo de DSP | Versión DCP | Complejidad |
|---|---|---|---|
Obtener datos de BRP | DMS | V3 - Internacional | Bajo |
Enviar datos a BRP | CRM | V4 - Norteamérica | Un poco más |
Transacción con BRP | | | Algo más |
Autenticación
La API está usando Autenticación de Aplicaciones.
Necesitas un token de acceso válido antes de llamar a esta API, o tienes que llamar a la API de Autenticación de Aplicaciones para obtener uno.
¡El token de acceso es válido por 30 minutos! (1799 segundos)
URL Base
Prueba | https://qa-cloud-api.brp.com/dcp/<v3 o v4> |
|---|---|
Producción | https://cloud-api.brp.com/dcp/<v3 o v4> |
Recurso: Inventario de Piezas del Concesionario
Este recurso actualiza el inventario de piezas del concesionario en el sistema BRP.
Representación JSON
{
"dealer_no": "0000691756",
"inventory_date": "{{INVENTORY_DATE}}",
"parts_inventory": [
{
"product_code": "420430408",
"qty_on_hand": 15,
"qty_dealer_stocking": 10,
"qty_available": 7,
"qty_min_stocking_level": 2,
"qty_max_stocking_level": 12,
"qty_best_stocking_level": 8,
"last_physical_inventory_date": "2022-02-01"
},
{
"product_code": "705800048",
"qty_on_hand": 6,
"qty_dealer_stocking": 4,
"qty_available": 2,
"qty_min_stocking_level": 1,
"qty_max_stocking_level": 6,
"qty_best_stocking_level": 3,
"last_physical_inventory_date": "2022-03-01"
}
]
}
Propiedades
Propiedad | Tipo | Definición | Notas |
|---|---|---|---|
dealer_no * | cadena | Código que identifica de manera única a un concesionario. Debe tener 10 caracteres. Si tiene menos de 10 caracteres, agregar '0' al inicio. | Longitud:10 |
inventory_date * | fecha-hora | La fecha en la que la instancia del inventario es reportada por la fuente, en formato ISO 8601. | Formato: YYYY-MM-DDTHH:MM:SSZ |
* Estos campos son obligatorios.
Recurso: Localizador de Piezas del Distribuidor
Este recurso se utiliza para localizar una pieza en el inventario del distribuidor.
Los concesionarios que tienen la pieza solicitada disponible en la cantidad requerida se devuelven y se ordenan por distancia, del más cercano al más lejano.
Si el concesionario que llama al servicio Dealer Part Locator tiene la pieza solicitada disponible en la cantidad requerida, el concesionario será el primero devuelto en la lista de concesionarioscon una distancia de 0.
Si la pieza no se encuentra, se devuelve una lista vacía de concesionarios.
Representación JSON
{
"req_product_code": "204130096",
"req_qty": "5",
"dealers": [
{
"dealer_no": "0000700916",
"dealer_name": "PERFORMANCE NC - PRINCEVILLE",
"address": {
"street": "780 BL. BARIL OUEST (RTE 116)",
"city": "PRINCEVILLE",
"state": "QC",
"country": "CA",
"postal_code": "G6L 3W6"
},
"language": "FR",
"time_zone": "UTC-05000",
"phone_no": "819-505-0712",
"distance": 0
},
{
"dealer_no": "0000691731",
"dealer_name": "MERCIER MARINE LTEE",
"address": {
"street": "3670 BOUL. FRONTENAC OUEST",
"city": "THETFORD MINES",
"state": "QC",
"country": "CA",
"postal_code": "G6H 2B8"
},
"language": "FR",
"time_zone": "UTC-05000",
"phone_no": "418-423-5517",
"distance": 42.3
},
{
"dealer_no": "0000694650",
"dealer_name": "PERFORMANCE N.C. INC.",
"address": {
"street": "176 BOUL. INDUSTRIEL",
"city": "ST-GERMAIN DE GRANTHAM",
"state": "QC",
"country": "CA",
"postal_code": "J0C 1K0"
},
"language": "FR",
"time_zone": "UTC-05000",
"phone_no": "819-395-2464",
"distance": 84.2
}
]
}Propiedades
Propiedad | Tipo | Definición | Notas |
|---|---|---|---|
req_product_code | string | Código de producto (igual que número de parte) solicitado por el concesionario | Longitud máxima:18 |
req_qty | integer | Cantidad solicitada por el concesionario | Formato: 999999 |
dealers | Lista de objetos | Lista de concesionarios que tienen la pieza solicitada en inventario |
|
dealers.dealer_no | string
| Número de concesionario. Debe tener 10 caracteres. Si tiene menos de 10 caracteres, añadir '0' al inicio. | Longitud:10 |
dealers.dealer_name | string | Nombre del concesionario | Longitud máxima:80 |
dealers .address | Objeto | Dirección del concesionario |
|
dealers.address. street | string | Dirección (1ª línea) | Longitud máxima:60 |
dealers.address .city | strin | Ciudad | Longitud máxima:40 |
dealers.address .state | string | Código que identifica de manera única una provincia/estado en un país, en formato ISO 3166-2 (2ª parte) | Longitud máxima:3 |
dealers.address .country | string | Código que identifica de manera única un país, en formato ISO 3166-1 | Longitud máxima:2 |
dealers.address .postal_code | string | Código postal del concesionario | Longitud máxima:10 |
dealers.language | string | Idioma de comunicación del concesionario en código de idioma ISO (ISO-639-1 + ISO 3166-1) | Formato xx-XX |
dealers.time_zone | string | Zona horaria correspondiente a la región del concesionario en ISO 8601. | Formato: UTC±HH:MM |
dealers.phone_no | string | Número de teléfono del concesionario | Longitud máxima:16 |
dealers.distance | decimal
| La distancia total entre el origen y el concesionario, basada en la unidad solicitada (km o mi). El cálculo se realiza en distancia de conducción si está disponible, y en línea recta en caso contrario. | Formato 99999.9 |
Limitaciones y restricciones
Consentimiento de Concesionarios de BRP Powersports y Uso Compartido de Datos
Su DMS solo debe enviar el inventario de repuestos de BRP Powersports concesionarios que hayan dado su consentimiento para compartir datos.
El inventario de repuestos enviado debe contener solo repuestos BRP.
Tamaño de la Carga Útil
La API de Inventario de Piezas del Concesionario se ejecuta en APIGee, que tiene un tamaño máximo de carga útil de 10 MB.
Como referencia, el límite de 10 MB representa un máximo de 30,000 piezas en la carga útil si se envían todos los campos opcionales.
Consulta la sección 413 Entidad de Solicitud Demasiado Grande para más información sobre cómo manejar el código de estado 413.
👉 Para evitar problemas con el límite de 10 MB de tamaño de carga útil, la API de Inventario de Piezas del Concesionario acepta un máximo de 30,000 piezas en tu carga útil.
Si el inventario del concesionario contiene más de 30,000 piezas, debes enviar tantas cargas útiles de 30,000 piezas como sea necesario.
Valor Máximo de Conteo
Todas las cantidades de inventario de piezas en la carga útil tienen un valor máximo de 999,999.
Algunos concesionarios están usando un valor muy alto de quantity_on_hand en su inventario para piezas pequeñas, como arandelas y tornillos, para evitar contarlas todas.
Para todos los valores de conteo superiores a 999,999, debes redondear el valor a 999,999 en la carga útil.
Localizador de Piezas del Concesionario y Cantidad Disponible
El recurso Localizador de Piezas del Distribuidor utiliza el valor de cantidad disponible en inventario para determinar si un distribuidor tiene la pieza solicitada en su inventario.
Una búsqueda más precisa utilizaría la cantidad disponible , que representa la cantidad que el distribuidor tiene disponible para liberar del inventario. Tradicionalmente se define como cantidad en existencia menos piezas reservadas o comprometidas.
Sin embargo, el valor de cantidad disponible es opcional en el inventario de piezas del distribuidor y actualmente no es una fuente confiable de información.
⛔ Número de pieza con '-'
A la fecha de este escrito, el servicio Buscar Pieza (Localizador de Piezas) no puede usarse con un número de pieza que contenga un '-'.
El problema está en la API backend llamada por la API DCP Dealer Parts Inventory. No hay ETA para una corrección en este momento.
Por ejemplo, la llamada:
GET https://cloud-api.brp.com/dcp/v4/part/3602-072/dealer-inventory?req_qty=1&dealer_no=0000708172
Devuelve un estado 400.
{
"status": 400,
"errors": [
{
"code": "invalid_query",
"title": "Invalid query parameters were specified",
"meta": [
{
"type": "field",
"value": "3602-072",
"msg": "product code must be alpha numeric",
"path": "product_code",
"location": "query"
}
]
}
]
}Referencia de API
curl --location 'https://qa-cloud-api.brp.com/dcp/v3/parts/dealer-inventory' \
--header 'Dealer-Number: 0000691756' \
--header 'Content-Type: application/json' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' \
--data '{
"dealer_no": "0000691756",
"inventory_date": "{{INVENTORY_DATE}}",
"parts_inventory": [
{
"product_code": "779140",
"qty_on_hand": 773,
"qty_dealer_stocking": 947,
"qty_available": 831,
"qty_min_stocking_level": 780,{{INVENTORY_DATE}}
"qty_max_stocking_level": 145,
"qty_best_stocking_level": 156,
"last_physical_inventory_date": "2022-12-02"
}
]
}'curl --location 'https://qa-cloud-api.brp.com/dcp/v4/part/204130096/dealer-inventory?req_qty=1&dealer_no=0000700916&unit=mi&radius=23' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' \
Cómo hacer
Esta sección proporciona información sobre cómo obtener resultados específicos con la API.
Encontrar una pieza en el inventario de los concesionarios
Busque un número de pieza con 5 unidades disponibles en el inventario de piezas de los concesionarios utilizando el radio predeterminado de 200 km.
En este ejemplo, el concesionario que solicita la pieza tiene al menos 5 en su inventario.
También hay otros 2 concesionarios con al menos 5 piezas disponibles en su inventario.
curl --location 'https://cloud-api.brp.com/dcp/v4/part/204130096/dealer-inventory?req_qty=5&dealer_no=0000700916' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Encontrar una pieza en concesionarios vecinos
Busque un número de pieza con 3 piezas disponibles en el inventario de piezas de los concesionarios dentro de un radio de 80 km.
En este ejemplo, el distribuidor que solicita la pieza tiene al menos 3 en su inventario.
También hay otro distribuidor con al menos 3 piezas disponibles en su inventario.
curl --location 'https://cloud-api.brp.com/dcp/v4/part/204130096/dealer-inventory?req_qty=3&dealer_no=0000700916&unit=km&radius=80' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Pieza solicitada no encontrada
Busque un número de pieza con 5 unidades disponibles en el inventario de piezas de los concesionarios dentro de un radio de 75 km. La lista de concesionarios está vacía si ningún concesionario tiene la pieza disponible en la cantidad solicitada.
curl --location 'https://cloud-api.brp.com/dcp/v4/part/12345678/dealer-inventory?req_qty=5&dealer_no=0000700916&unit=km&radius=75' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Gestión de errores
Esta sección presenta varios escenarios de llamadas incorrectas o inapropiadas, que resultan en mensajes de error y resultados incorrectos.
Inventario de Piezas del Concesionario
400 Solicitud Incorrecta
El código de estado 400 se encuentra típicamente durante el desarrollo y la integración, y no debería recibirse durante las operaciones normales. La respuesta devuelta contiene la información necesaria para corregir el problema.
Muchos problemas pueden causar un código de estado 400; los más comunes se enumeran en la tabla a continuación.
Respuesta | Resolución |
|---|---|
Se devuelve si el número de concesionario no es válido. {
"status": 400,
"id": "rrt-0570f...",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "El número de concesionario proporcionado no existe o no es válido."
}
} | Si el concesionario está utilizando tu DMS, puede deberse a que ya no es un concesionario BRP. Verifícalo con ellos y desactiva las actualizaciones del inventario de repuestos. Asegúrate de que el número de concesionario tenga 10 caracteres. Si guardas el número sin el '0' inicial, agrégalo antes de llamar a la API. El error también se devuelve si el concesionario no es un concesionario BRP activo. |
Se devuelve si la fecha de inventario tiene un formato no válido. {
"status": 400,
"id": "rrt-0570f8640a6...",
"title": "bad_request",
"meta": {
"service": "01",
"code": "request validation failed",
"errors": {
"details": [
{
"message": "[Path '/inventory_date'] La cadena \"25-11-2023T15:18:58Z\" no es válida según el formato requerido [yyyy-MM-dd'T'HH:mm:ssZ, yyyy-MM-dd'T'HH:mm:ss.[0-9]{1,12}Z]: []"
}
]
}
}
} | Cambia el formato de la cadena de fecha para que coincida con el formato del payload. |
Se devuelve si una cantidad supera el límite. {
"status": 400,
"id": "rrt-0debaee1f7de5...",
"title": "bad_request",
"meta": {
"service": "01",
"code": "request validation failed",
"errors": {
"details": [
{
"message": "[Path '/parts_inventory/0/qty_on_hand'] La instancia numérica es mayor que el máximo permitido (máximo: 999999, encontrado: 1000000): []"
}
]
}
}
} | Todas las cantidades en el payload tienen un valor máximo de 999,999. Si tu DMS permite un valor mayor y el concesionario lo usa, debes redondear el valor a 999,999 antes de enviar el inventario de repuestos. |
La lista de repuestos está vacía. {
"status": 400,
"id": "rrt-0cdea36b8097f17...",
"title": "bad_request",
"meta": {
"service": "07",
"payload": {
"errors": "El arreglo 'parts_inventory' no debe estar vacío."
}
}
} | El payload enviado tiene una lista de repuestos vacía. Al aplicar los filtros definidos en la Requisitos Funcionales no envíes el inventario de repuestos si la lista está vacía. En teoría, esto nunca debería ocurrir ya que significaría que todas las piezas BRP tienen una quantity_on_hand de 0. |
Se devuelve si el payload contiene más de 30,000 elementos. {
"status": "400",
"id": "rrt-06c1b7ac7365beb8f-d-ea-22696-1347602-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "request validation failed",
"payload": {
"details": [
{
"message": "[Path '/parts_inventory'] El arreglo es demasiado largo: debe tener como máximo 30000 elementos, pero la instancia tiene 40000 elementos: []"
}
]
}
}
} | Divide el inventario de repuestos para enviar varios payloads con un máximo de 30,000 elementos por cada uno. |
Este es un ejemplo de una llamada al servicio de Inventario de Piezas del Concesionario que devuelve un código de estado 400 Solicitud Incorrecta.
curl --location 'https://qa-cloud-api.brp.com/dcp/v3/parts/dealer-inventory' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' \
--data '{
"dealer_no": "1234567890",
"inventory_date": "2022-11-23T15:18:58Z",
"parts_inventory": [
{
"product_code": "779140",
"qty_on_hand": 15,
"qty_dealer_stocking": 10,
"qty_available": 7,
"qty_min_stocking_level": 2,
"qty_max_stocking_level": 12,
"qty_best_stocking_level": 8,
"last_physical_inventory_date": "2022-02-01"
}
]
}'413 Entidad de solicitud demasiado grande
El código de estado 413 Request Entity Too Large se devuelve cuando la carga supera el límite de 10 MB de APIGee.
Tenga en cuenta que el código de estado 413 puede recibirse incluso si la carga que está enviando tiene menos de 10 MB. La carga se procesa y convierte antes de ser enviada a una API interna de BRP, y esta API interna puede devolver un código de estado 413.
Para corregir el problema:
- Envíe solo las partes que tengan un valor distinto de cero.
- No las envíe si el concesionario no está utilizando las propiedades opcionales, como qty_min_stocking_level.
401 No Autorizado
El código de estado de error 401 No Autorizado se devuelve cuando intenta llamar a la API Dealer Parts Inventory con un access_token expirado.
Debe obtener un nuevo access_token con una llamada a la API de Autenticación de Aplicaciones.
Localizador de Piezas del Concesionario
400 Solicitud Incorrecta
El código de estado 400 se encuentra típicamente durante el desarrollo y la integración, y no debería recibirse durante las operaciones normales. La respuesta devuelta contiene la información necesaria para corregir el problema.
Muchos problemas pueden causar un código de estado 400; los más comunes se encuentran en la tabla a continuación.
Respuesta | Resolución |
|---|---|
Falta el código del producto {
"status": 400,
"id": "rrt-0570f8640a6f6e...",
"title": "bad_request",
"meta": {
"service": "01",
"code": "request validation failed",
"errors": {
"details": [
{
"message": "El parámetro de consulta 'sales_org' es requerido en la ruta '/part/{part_number}' pero no se encontró en la solicitud."
},
{
"message": "El parámetro de consulta 'currency' es requerido en la ruta '/part/{part_number}' pero no se encontró en la solicitud."
},
{ | Falta el número de pieza (código del producto) en la consulta. |
Número de distribuidor inválido {
"status": 400,
"id": "rrt-0b8f470f8a6f5fd93-d-ea-19152-79657993-1.1",
"title": "not_found",
"meta": [
{
"service": "07",
"payload": {
"errors": {
"error_id": "4042",
"error_message": "El dealer_no es inválido"
}
}
}
]
} | Si el distribuidor usa tu DMS, puede ser porque ya no es un distribuidor BRP. Verifica con ellos y desactiva las actualizaciones de inventario de repuestos. Asegúrate de que el número de distribuidor tenga 10 caracteres. Si guardas el número sin el '0' inicial, agrega el '0' inicial antes de llamar a la API. |
Código de producto inválido (número de pieza) {
"status": 404,
"id": "rrt-0b8f470f8a6f...",
"title": "not_found",
"meta": [
{
"service": "07",
"payload": {
"errors": {
"error_id": "4043",
"error_message": "El product_no es inválido"
}
}
}
]
} | Todas las cantidades en el payload tienen un valor máximo de 999,999. Si tu DMS permite un valor más alto y el distribuidor lo usa, debes redondear el valor a 999,999 antes de enviar el inventario de repuestos. |
401 No Autorizado
El código de estado de error 401 No Autorizado se devuelve cuando intentas llamar a la API con un access_token expirado.
Tienes que obtener un nuevo access_token con una llamada a la API de Autenticación de Aplicaciones.
El código de estado de error 401 Unauthorized también se devuelve si no solicitaste acceso a la API creando un ticket en el Jira de DCP.
Cuando estés listo para comenzar a trabajar en una API, debes crear un ticket de certificación en Jira, como se describe en la sección Actividades de Certificación con Jira.
Si ya comenzaste a trabajar en una API y perdiste acceso, crea un ticket de soporte como se describe en la sección Abrir un Ticket de Soporte.
404 No Encontrado
El código de estado 404 Not Found es devuelto solo por la versión V3 si el número de parte es inválido.
En V4, se devuelve una lista vacía de distribuidores cuando no se encuentra el número de parte.
El código de estado 404 Not Found se devuelve cuando no se encuentra la parte.
curl --location 'https://qa-cloud-api.brp.com/dcp/v3/part/123456789/dealer-inventory?req_qty=2&dealer_no=0000691737&unit=mi&radius=170.2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Corrección
El concesionario puede haber ingresado un número de pieza no válido.
Requisitos DSP
Requisitos funcionales
ID | Tipo | Requisito |
|---|---|---|
1 | Obligatorio | El inventario de piezas del concesionario debe enviarse automáticamente a diario, incluso si el concesionario está cerrado, fuera del horario comercial del concesionario, para todos los concesionarios que hayan dado su consentimiento para compartir datos. ❗ El inventario de piezas del concesionario debe enviarse automáticamente sin una acción manual del concesionario ❗ |
2 | Obligatorio | Solo las piezas BRP deben enviarse al inventario del concesionario. Las piezas de otros OEM y las piezas definidas por el concesionario no deben enviarse. |
4 | Obligatorio | Para todos los valores mayores a 999,999, redondee el valor a 999,999. |
5 | Obligatorio | Su DMS debe enviar un máximo de 30,000 piezas en una carga útil. Si hay más de 30,000 piezas en el inventario del concesionario, debe enviar tantas cargas útiles de 30,000 piezas como sean necesarias. |
6 | Obligatorio | Solo el inventario de piezas de los concesionarios BRP Powersports debe enviarse cuando el concesionario haya dado su consentimiento para compartir datos. |
7 | Obligatorio | Si el concesionario retira el consentimiento para compartir datos y deja de ser un concesionario BRP, la transmisión de datos del inventario de piezas debe deshabilitarse. |
8 | Obligatorio | El inventario de piezas del concesionario debe llamarse para enviar el inventario completo de piezas del concesionario, NO una pieza a la vez. |
Actividades de certificación
Esta sección presenta todas las actividades de certificación y validaciones que deben completarse para certificar la API.
Aseguramiento de la calidad - POST
Las pruebas enumeradas en la tabla a continuación deben realizarse correctamente en el entorno de prueba antes de que pueda comenzar la fase piloto del concesionario.
ID | Prueba | Resultado esperado |
|---|---|---|
1 | Enviar el inventario de una pieza | El inventario ha sido recibido y no hay errores en el registro de la API. |
2 | Enviar un inventario completo del concesionario | El inventario ha sido recibido y no hay errores en el registro de la API. El equipo de DCP verifica que el inventario de piezas no contenga piezas que no sean de BRP. |
3 | Todo el inventario recibido | El inventario de piezas es recibido para todos los concesionarios que han dado su consentimiento para compartir datos. |
4 | El inventario se actualiza | Verificar que el inventario del concesionario esté actualizado, es decir, que la cantidad de algunas piezas cambie con el tiempo. |
5 | Enviar el inventario con datos divididos | Verificar que se envíen múltiples cargas si el inventario del concesionario supera las 30,000 piezas. 👉 Si el inventario del concesionario usado para pruebas tiene menos de 30,000 piezas, debe cambiar el límite en su DMS para enviar al menos 2 cargas. |
6 | Actualizaciones automáticas | Verificar que el inventario se envíe automáticamente durante 5 días consecutivos. |
Garantía de calidad - GET
Las pruebas enumeradas en la tabla a continuación deben completarse en el entorno de prueba antes de que pueda comenzar la fase piloto del concesionario.
ID | Prueba | Resultado esperado |
|---|---|---|
1 | Buscar la pieza 517308658 sin un radio y con una cantidad de 1 | Se debería encontrar una lista de distribuidores. |
2 | Buscar la pieza 517308658 con un radio de 100 mi o km y una cantidad de 10 | Se debería encontrar una lista de distribuidores. |
3 | Buscar la pieza 517308658 con un radio de 15000 mi o km y una cantidad de 3 | Se debería encontrar una lista de distribuidores. |
4 | Buscar la pieza 219400698 con un radio de 75 mi o km y una cantidad de 5 | La lista de distribuidores debería estar vacía. |
Los siguientes números de pieza están disponibles para pruebas:
- 715005683
- 517308658
- 219906024
- 706203893
- 224081201
- 9779126
- S40100RCA000
Piloto de concesionario
La siguiente tabla describe los parámetros del piloto de concesionario y sus validaciones correspondientes.
Parámetro | Valor |
|---|---|
Entorno | Producción |
Número de distribuidores | 1 a 3 |
Duración | 1 semana |
Validación 1 | El equipo de DCP verifica que el inventario de repuestos de los distribuidores se recibe diariamente. |
Validación 2 | El equipo de DCP verifica que el inventario de repuestos de los distribuidores no contiene piezas que no sean de BRP. |
Validación 3 | Para cada distribuidor en el piloto, exporta el inventario del distribuidor a un archivo Excel, CSV o JSON durante 5 días (los días no necesitan ser consecutivos). El equipo de DCP valida que el inventario recibido coincide con el inventario en los archivos exportados. |
Validación 4 | El equipo de DCP verifica que no haya errores en el registro de la API. |
Validación 5 | Enviar capturas de pantalla de los resultados de búsqueda del localizador de piezas. Una pieza buscada para cada línea de productos compatible con el distribuidor, para cada distribuidor. |
Cartero
Esta sección describe lo que está disponible en Postman para explorar la API.
Entornos
Un entorno de Postman está disponible para probar la API de Inventario de Piezas del Concesionario. Este entorno de Postman contiene variables que las consultas utilizan y está configurado para conectarse al entorno de prueba.
Colecciones
La colección DMS - Inventario de Piezas del Concesionario incluye ejemplos de llamadas a la API para actualizar el inventario de piezas de un concesionario y buscar una pieza en él.